%% PCA + Hirarchical clustering 
%  cluster cells with all cue-predicted responses (CS1, CS2, CS3)
%  Inputs (required): Data.DFzscore
%  Outputs ---- clustering figure
%% clear all except
close all
clearvars -except Data1 Data2 Data3
%% define parameters
n1 = -3; n2 = 2; % SD
nCluster = 2;
% baseline = [71 100]; % baseline window
stimulation = [121 130]; % stimulation window
Zscore1 = Data1.DFzscore; % CS1
Zscore2 = Data2.DFzscore; % CS2
Zscore3 = Data3.DFzscore; % CS3

data1 = Zscore1(:,stimulation(1):stimulation(2)); % CS1
data2 = Zscore2(:,stimulation(1):stimulation(2)); % CS2
data3 = Zscore3(:,stimulation(1):stimulation(2)); % CS3
data = [data1 data3];
%% Run PCA
[eigvect,proj,eigval] = pca(data);
proj123 = proj(:,1:3);
% figure,plot3(proj123(:,1),proj123(:,2),proj123(:,3),'o')

% Hierarchical clustering
figure;
cosD = pdist(proj123,'correlation');
clustTreeCos = linkage(cosD,'complete');
cophenet(clustTreeCos,cosD)
[h,nodes] = dendrogram(clustTreeCos,0);
h_gca = gca;
h_gca.TickDir = 'out';
h_gca.TickLength = [.002 0];
T = cluster(clustTreeCos,'maxclust',nCluster);

% ranking = str2num(get(gca,'XTicklabel'));
%% sort and plot figure
[A B] = sort(T,'descend');
ranking = B;
for i = 1:length(ranking)
   data_ranking(i,:) = data(ranking(i),:);
   proj123_ranking(i,:) = proj123(ranking(i),:);
   
   Zscore1_ranking(i,:) = Zscore1(ranking(i),:); 
   Zscore2_ranking(i,:) = Zscore2(ranking(i),:);
   Zscore3_ranking(i,:) = Zscore3(ranking(i),:);
end

% Plot heatmap of ranked auROC
% colorspace
Parameter.colorR = 28; % for colorspace, do not need to change
Parameter.colorC = 28; % for colorspace, do not need to change
colorspace = zeros(64,3);
colorspace(64-Parameter.colorR+1:64,1) = linspace(0,1,Parameter.colorR); % RGB color space, define R value here
colorspace(1:Parameter.colorC,2) = linspace(1,0,Parameter.colorC); % G
colorspace(1:Parameter.colorC,3) = linspace(1,0,Parameter.colorC); % B

figure,imagesc(data_ranking,[n1 n2]);
colormap(colorspace)

figure,imagesc(Zscore1_ranking,[n1 n2]);
colormap(colorspace)
figure,imagesc(Zscore2_ranking,[n1 n2]);
colormap(colorspace)
figure,imagesc(Zscore3_ranking,[n1 n2]);
colormap(colorspace)
%% imshow PCA123
enlagre_factor = ones(10,200);
K = kron(proj123_ranking,enlagre_factor);
h3 = figure; imshow(K,[min(K(:))*0.5 max(K(:))*0.5])
% h3 = figure; imshow(K,[-2 2])
set(gcf,'color','[1 1 1]')
%% plot curve of different clusters
for i = 1:nCluster
    CS1T1 = Zscore1(T==i,:);
    CS2T1 = Zscore2(T==i,:);
    CS3T1 = Zscore3(T==i,:);
    figure,plot(mean(CS1T1),'Color',[0 0.8 0]); hold on;
    shadedErrorBar([1:200],mean(CS1T1),std(CS1T1)/sqrt(size(CS1T1,1)),'g');
    plot(mean(CS2T1),'Color',[0 0 0])
    shadedErrorBar([1:200],mean(CS2T1),std(CS2T1)/sqrt(size(CS2T1,1)),'K');
    plot(mean(CS3T1),'Color',[0.8 0 0])
    shadedErrorBar([1:200],mean(CS3T1),std(CS3T1)/sqrt(size(CS3T1,1)),'r');
    ylim([-1 2])
    xlabel('Time (s)')
    ylabel('Zscore')
    box off
    set(gcf,'color','[1 1 1]')
    filename = strcat('cluster',num2str(i));
    title(filename)
end