%% nchoosek and cumulative probability distribution function ploting
% Inputs:   ROIs ---------------------------ROI matrix for all cells
%           ROIsize ------------------------rows columns
%           T ------------------------------reward or punishment cells
% Outputs:  CDF figure
%% All cells
nCells = size(ROIs,2); % define cell number
C = nchoosek(1:nCells,2); % pairwise
for j = 1:nCells
    ROIarray = ROIs(:,j);
    ROImatrix = reshape(ROIarray,ROIsize(1),ROIsize(2));
    ROImatrix(ROImatrix>0) = 1;
    stats  = regionprops(ROImatrix,'centroid');
    Centroids(j,:) = stats.Centroid;
end
% pairwise calculation
for i = 1:size(C,1)
    ind1 = C(i,1);
    ind2 = C(i,2);
    
    Distance(i) = norm(Centroids(ind1,:) - Centroids(ind2,:)); % or Distance(i) = pdist([(Centroids(ind1,:);Centroids(ind2,:))],'euclidean');
end

figure;
Distance = Distance.*1.667; % pixel to micro meter
h = cdfplot(Distance);
%% Reward cells
Centroids1 = Centroids(T==2,:);
C1 = nchoosek(1:size(Centroids1,1),2); % pairwise
% pairwise calculation
for i = 1:size(C1,1)
    ind1 = C1(i,1);
    ind2 = C1(i,2);
    
    Distance1(i) = norm(Centroids1(ind1,:) - Centroids1(ind2,:)); % or Distance(i) = pdist([(Centroids(ind1,:);Centroids(ind2,:))],'euclidean');
end
hold on;
Distance1 = Distance1.*1.667; % pixel to micro meter
cdfplot(Distance1);
%% Punishment cells
Centroids2 = Centroids(T==3,:);
C2 = nchoosek(1:size(Centroids2,1),2); % pairwise
% pairwise calculation
for i = 1:size(C2,1)
    ind1 = C2(i,1);
    ind2 = C2(i,2);
    
    Distance2(i) = norm(Centroids2(ind1,:) - Centroids2(ind2,:)); % or Distance(i) = pdist([(Centroids(ind1,:);Centroids(ind2,:))],'euclidean');
end
hold on;
Distance2 = Distance2.*1.667; % pixel to micro meter
cdfplot(Distance2);
xlabel('Pairwise neuronal distance (?m)')
ylabel('Cumulative probability')
%% Two-sample Kolmogorov-Smirnov test
[h1,p1] = kstest2(Distance,Distance1)
[h2,p2] = kstest2(Distance,Distance2)
% legend('All','reward','punishment','Location','NW')
% h.BinWidth = 0.1;
% nanmean(NoiseCorrcoef)
% save m6 NoiseCorrcoef
%% probility density ploting
figure; ksdensity(Distance)
hold on;
ksdensity(Distance1)
ksdensity(Distance2)




