function PhotometryUS
%% Prelearning_Imaing is for one photon prelearning imaging 
% 0:sucrose, quinine, fat; 1:tailshock
% SETUP
% > Connect the water valve in the box to Bpod Port#1.
% > Connect the air valve in the box to Bpod Port#2.
% > Lick: Bpod Port#3
% > Running: Wire 1 (input)
% > Imaging: Wire 1 (output)
% > BNC1: tail shock
global BpodSystem
%% Define parameters
S = BpodSystem.ProtocolSettings; % Load settings chosen in launch manager into current workspace as a struct called S
if isempty(fieldnames(S))  % If settings file was an empty struct, populate struct with default settings
    S.RndFlag = 0; % Deploy t  he random trials or repeat a list of trials. 
    S.NonrandomMaxTrials = 10; %Total number of trials to run. This should not exceed the limit of the grapher (BpodSystem.PluginObjects.maxTrials)
%     S.NonrandomSequence = [zeros(1,20),ones(1,20)]; % If nonrandom, sequence of the trials to run. 
   	S.GUI.BaselineTime = 10;
    S.GUI.RewardAmount = 1; % ul
    S.TrialType = 0; % 0:sucrose, quinine, fat; 1:tailshock
    S.GUI.PunishAmount = 0.5; % s (air puff)
    S.arduinoPort = 'COM9'; % Port (USB) of the wheel run sensor Arduino
	S.wheelCirc = 46; % Circumference of the wheel (cm)
	S.wheelTicks = 1024; % Number of ticks recorded by the wheel per rotation.
	S.wheelMult = S.wheelCirc/S.wheelTicks; % Distance per tick (cm)
    %Attempt to connect to the Arduino run detector. 
	BpodSystem.PluginObjects.ardSerial = serial(S.arduinoPort);
    BPAS = BpodSystem.PluginObjects.ardSerial;
	BPAS.InputBufferSize = 16000; % read up to 2kb
	set(BPAS,'DataBits',8);
	set(BPAS,'StopBits',1);
	set(BPAS,'BaudRate',115200);
	set(BPAS,'Parity','none');
	fopen(BPAS);
	autoCleanup = onCleanup(@()fclose(BPAS));
    
    S.ITI = 6;
    S.ITI_min = 5; S.ITI_max = 7;
end

LickPort = 'Port3In';
RunPort = 'Wire1High';
RewardValveState = 1;
% PunishValveState = 2;

% Initialize parameter GUI plugin
BpodParameterGUI('init', S);
TotalRewardDisplay('init');

%% Define trials
if (~S.RndFlag && BpodSystem.PluginObjects.maxTrials < S.NonrandomMaxTrials)
    MaxTrials = BpodSystem.PluginObjects.maxTrials;
else
    MaxTrials = S.NonrandomMaxTrials;
end


    TrialTypes = [zeros(20,1)]';

BpodSystem.Data.TrialTypes = []; % The trial type of each trial completed will be added here.
BpodSystem.Data.ITI = [];
BpodSystem.Data.RunEvents = [];
BpodSystem.Data.RunSpeed = {};
BpodSystem.Data.CurrentTrialRunSpeed = zeros(10000,2);
BpodSystem.Data.CurrentTrialRunEvents = 0;
%% Initialize plots
BpodSystem.ProtocolFigures.SideOutcomePlotFig = figure('Position', [500 200 800 300],'name','Outcome plot','numbertitle','off', 'MenuBar', 'none', 'Resize', 'off');
BpodSystem.GUIHandles.SideOutcomePlot = axes('Position', [.075 .3 .89 .6]);
GoNoGoOutcomePlot_pus(BpodSystem.GUIHandles.SideOutcomePlot,'init',TrialTypes);

% BpodSystem.ProtocolFigures.LickPlotFig = figure('Position', [600 200 600 200],'name','Licking','numbertitle','off', 'MenuBar', 'none', 'Resize', 'off');
% Set soft code handler to trigger sounds
BpodSystem.SoftCodeHandlerFunction = 'SoftCodeHandler_PlaySoundX';
%% Main trial loop
T = timer('period',1,'executionmode','fixedrate','taskstoexecute',9999999);
T.TimerFcn = @(~,~)scriptMonitor();
T.Period = 1;
T.ExecutionMode = 'fixedRate';
start(T);
autoTimerCleanup = onCleanup(@()delete(timerfind));
for currentTrial = 1:MaxTrials
    S = BpodParameterGUI('sync', S); % Sync parameters with BpodParameterGUI plugin
    R = GetValveTimes(S.GUI.RewardAmount, [1]);
    RewardValveTime = R;  
    sma = NewStateMatrix(); % Assemble state matrix
    sma = SetGlobalTimer(sma,  'TimerID', 1, 'Duration',20, 'OnsetDelay', 0, 'Channel', 'Wire2');
          
    
     switch S.TrialType 
         case 0
             
            %Global timer for synchronising events. Timer1: Sound, Timer2: Actions. 
        
             
             sma = AddState(sma, 'Name', 'TrialStart', ...%1
                  'Timer', S.GUI.BaselineTime,...
                  'StateChangeConditions', {'Tup', 'AssistReward'},...
                  'OutputActions', {'GlobalTimerTrig', 1});
             sma = AddState(sma, 'Name', 'AssistReward', ...%4
                   'Timer', 0,...
                   'StateChangeConditions', {'Tup', 'DeliverReward'},...
                   'OutputActions', {});
             sma = AddState(sma, 'Name', 'DeliverReward', ...%5
                    'Timer', RewardValveTime,...
                    'StateChangeConditions', {'Tup', 'FinalSync'},...
                    'OutputActions', {'ValveState', RewardValveState});
              
         case 1
             %Global timer for synchronising events. Timer1: Sound, Timer2: Actions. 
        
             sma = AddState(sma, 'Name', 'TrialStart', ...%1
                  'Timer', S.GUI.BaselineTime,...
                  'StateChangeConditions', {'Tup', 'AssistPunishment'},...
                  'OutputActions', {'GlobalTimerTrig', 1});
             sma = AddState(sma, 'Name', 'AssistPunishment', ...%4
                   'Timer', 0,...
                   'StateChangeConditions', {'Tup', 'DeliverPunishment'},...
                   'OutputActions', {});
             sma = AddState(sma, 'Name', 'DeliverPunishment', ...%5
                    'Timer', S.GUI.PunishAmount,...
                    'StateChangeConditions', {'Tup', 'FinalSync'},...
                    'OutputActions', {'BNC1', 1});
             
     end
              
        sma = AddState(sma, 'Name', 'FinalSync', ...%6
            'Timer', 0,...
            'StateChangeConditions', {'Tup', 'EndTime'},...
            'OutputActions', {});
        
        sma = AddState(sma, 'Name', 'EndTime', ...%7
            'Timer', S.GUI.BaselineTime,...
            'StateChangeConditions', {'Tup', 'ITI'},...
            'OutputActions', {});
        
        sma = AddState(sma, 'Name', 'ITI', ...%8
            'Timer', S.ITI,...
            'StateChangeConditions', {'Tup', 'exit'},...
            'OutputActions', {});
     
	BpodSystem.ProtocolFigures.CurrentTrialStartTime = datenum(datetime)*86400-BpodSystem.ProtocolFigures.StartTime;
    BpodSystem.Data.CurrentTrialRunSpeed = zeros(10000,2);
    BpodSystem.Data.CurrentTrialRunEvents = 0;
    SendStateMatrix(sma);
    RawEvents = RunStateMatrix;
	BpodSystem.Data.CurrentTrialLickTimes = [];
    if ~isempty(fieldnames(RawEvents)) % If trial data was returned
		%disp(RawEvents);
		RE = RawEvents.Events;
        %disp(RE);
		RES = RawEvents.States;
        %disp(RES);
		REST = RawEvents.StateTimestamps(2:end);
		%disp(REST);
		RET = RawEvents.EventTimestamps;
        %disp(RET);
		%Find if any timestamps contain a reward deliver (event 13) and
		%record that as the current trial reward delivery timestamp.
		RESR = (RES==13);
		%disp(RESR);
		BpodSystem.Data.CurrentTrialRewardTime = round(BpodSystem.ProtocolFigures.CurrentTrialStartTime+sum(RESR.*REST));
		%Filter the timestamps for licks (In3Up, 53/30 depending on computer) 
		%and turn them into a list.
		REE = (RE==32);
		BpodSystem.Data.CurrentTrialLickTimes = round(nonzeros(REE.*RET)+BpodSystem.ProtocolFigures.CurrentTrialStartTime);
        %disp(BpodSystem.Data.CurrentTrialLickTimes)
        BpodSystem.Data = AddTrialEvents(BpodSystem.Data,RawEvents); % Computes trial events from raw data
        BpodSystem.Data.TrialSettings(currentTrial) = S; % Adds the settings used for the current trial to the Data struct (to be saved after the trial ends)
        BpodSystem.Data.TrialTypes(currentTrial) = TrialTypes(currentTrial); % Adds the trial type of the current trial to data
        %Outcome
                
        %Save the run timings and speeds
        BpodSystem.Data.RunEvents(currentTrial) = BpodSystem.Data.CurrentTrialRunEvents;
        BpodSystem.Data.RunSpeed{currentTrial} = BpodSystem.Data.CurrentTrialRunSpeed;
        
        UpdateTotalRewardDisplay(S.GUI.RewardAmount, currentTrial);
        UpdateGoNoGoOutcomePlot_pus(TrialTypes, BpodSystem.Data);
        SaveBpodSessionData; % Saves the field BpodSystem.Data to the current data file
    end
    HandlePauseCondition; % Checks to see if the protocol is paused. If so, waits until user resumes.
    if BpodSystem.Status.BeingUsed == 0
        return
    end
end

function UpdateGoNoGoOutcomePlot_pus(~, Data)
	Outcomes = ones(1,Data.nTrials);
	GoNoGoOutcomePlot_pus(BpodSystem.GUIHandles.SideOutcomePlot,'update',Data.nTrials+1,TrialTypes,Outcomes);
end

end

function UpdateTotalRewardDisplay(RewardAmount, currentTrial)
% If rewarded based on the state data, update the TotalRewardDisplay
global BpodSystem
    HasReward = 0;
    if (~isnan(BpodSystem.Data.RawEvents.Trial{currentTrial}.States.FinalSync(1)))
        HasReward = 1;
    end
    TotalRewardDisplay('add', RewardAmount*HasReward);
end

function scriptMonitor()
	%Runs every second to monitor background events. 
	global BpodSystem
    S = BpodSystem.ProtocolSettings;
	%Reads the data from the Arduino serial port. 
    BPAS = BpodSystem.PluginObjects.ardSerial;
	dataSize = get(BPAS,'BytesAvailable');
	if (dataSize>0)
		inASCII = fread(BPAS,dataSize);
		inData = transpose(char(inASCII));
		inData = strsplit(inData);
		inData = inData(1:end-1); % Remove the last newline from the array
		for k=1:length(inData) % Convert the array to run speed / run distance and write it to the run speed array. 
			BpodSystem.Data.CurrentTrialRunSpeed(k+BpodSystem.Data.CurrentTrialRunEvents,1:2) = str2double(strsplit(inData{k},'A'));
        end
        BpodSystem.Data.CurrentTrialRunEvents = BpodSystem.Data.CurrentTrialRunEvents + length(inData);
		assignin('base', 'inString', BpodSystem.Data.CurrentTrialRunEvents);
	end
	TotalRewardDisplay('update');
end

